==> aws-cdk-scala-stepfunctions_2.12-0.1.7-sources.jar: io/burkard/cdk/services/stepfunctions/SageMakerCreateEndpointConfigProps.scala <==
package io.burkard.cdk.services.stepfunctions

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object SageMakerCreateEndpointConfigProps {

  def apply(
    productionVariants: List[_ <: software.amazon.awscdk.services.stepfunctions.tasks.ProductionVariant],
    endpointConfigName: String,
    kmsKey: Option[software.amazon.awscdk.services.kms.IKey] = None,
    tags: Option[software.amazon.awscdk.services.stepfunctions.TaskInput] = None,
    resultPath: Option[String] = None,
    resultSelector: Option[Map[String, _]] = None,
    heartbeat: Option[software.amazon.awscdk.Duration] = None,
    integrationPattern: Option[software.amazon.awscdk.services.stepfunctions.IntegrationPattern] = None,
    outputPath: Option[String] = None,
    comment: Option[String] = None,
    inputPath: Option[String] = None,
    timeout: Option[software.amazon.awscdk.Duration] = None
  ): software.amazon.awscdk.services.stepfunctions.tasks.SageMakerCreateEndpointConfigProps =
    (new software.amazon.awscdk.services.stepfunctions.tasks.SageMakerCreateEndpointConfigProps.Builder)
      .productionVariants(productionVariants.asJava)
      .endpointConfigName(endpointConfigName)
      .kmsKey(kmsKey.orNull)
      .tags(tags.orNull)
      .resultPath(resultPath.orNull)
      .resultSelector(resultSelector.map(_.asJava).orNull)
      .heartbeat(heartbeat.orNull)
      .integrationPattern(integrationPattern.orNull)
      .outputPath(outputPath.orNull)
      .comment(comment.orNull)
      .inputPath(inputPath.orNull)
      .timeout(timeout.orNull)
      .build()
}

==> aws-cdk-scala-stepfunctions_2.13-0.4.1-sources.jar: io/burkard/cdk/services/stepfunctions/SageMakerCreateEndpointConfigProps.scala <==
package io.burkard.cdk.services.stepfunctions

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object SageMakerCreateEndpointConfigProps {

  def apply(
    productionVariants: List[_ <: software.amazon.awscdk.services.stepfunctions.tasks.ProductionVariant],
    endpointConfigName: String,
    kmsKey: Option[software.amazon.awscdk.services.kms.IKey] = None,
    tags: Option[software.amazon.awscdk.services.stepfunctions.TaskInput] = None,
    resultPath: Option[String] = None,
    integrationPattern: Option[software.amazon.awscdk.services.stepfunctions.IntegrationPattern] = None,
    outputPath: Option[String] = None,
    comment: Option[String] = None,
    resultSelector: Option[Map[String, _]] = None,
    inputPath: Option[String] = None,
    timeout: Option[software.amazon.awscdk.Duration] = None,
    heartbeat: Option[software.amazon.awscdk.Duration] = None
  ): software.amazon.awscdk.services.stepfunctions.tasks.SageMakerCreateEndpointConfigProps =
    (new software.amazon.awscdk.services.stepfunctions.tasks.SageMakerCreateEndpointConfigProps.Builder)
      .productionVariants(productionVariants.asJava)
      .endpointConfigName(endpointConfigName)
      .kmsKey(kmsKey.orNull)
      .tags(tags.orNull)
      .resultPath(resultPath.orNull)
      .integrationPattern(integrationPattern.orNull)
      .outputPath(outputPath.orNull)
      .comment(comment.orNull)
      .resultSelector(resultSelector.map(_.asJava).orNull)
      .inputPath(inputPath.orNull)
      .timeout(timeout.orNull)
      .heartbeat(heartbeat.orNull)
      .build()
}
